<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2020 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

/** @var FOF30\View\DataView\Html $this */

use Akeeba\TicketSystem\Admin\Helper\ComponentParams;
use Akeeba\TicketSystem\Admin\Helper\Editor;
use Akeeba\TicketSystem\Admin\Model\Posts;

// No direct access
defined('_JEXEC') or die;

// Please note: can't extend the common/Edit template since we're going to do some tricks on the form element

$component = JComponentHelper::getParams('com_ats');

if(!isset($quickreply))
{
    $quickreply = !($this->item instanceof Posts);
}

if(!isset($ats_ticket_id))
{
	$ats_ticket_id = 0;

	if(isset($this->item->ats_ticket_id))
    {
        $ats_ticket_id = $this->item->ats_ticket_id;
    }
}

if(!isset($ats_post_id))
{
	$ats_post_id = 0;

	if(isset($this->item->ats_post_id))
    {
        $ats_post_id = $this->item->ats_post_id;
    }
}

if(!isset($returnURL))
{
	$returnURLtemp = $this->input->getString('returnurl',null);

	if(!empty($returnURLtemp))
    {
        $returnURL = $returnURLtemp;
    }
}

$js = <<<JS
akeeba.jQuery(document).ready(function(jQuery){
    jQuery('#addAttachment').click(function(){
        if(jQuery('input[name="attachedfile[]"]').length >= 10)
        {
            return false;
        }

        var clone = jQuery('.attachmentWrapper').first().clone();
        clone.children('input').val('');
        clone.children('a').css('display', 'inline-block');

        clone.appendTo('.attachmentHolder');
    })

    jQuery('.attachmentHolder').on('click', '.attachmentWrapper a', function(){
        jQuery(this).parent().remove();
    });
})
JS;

?>
@inlineJs($js)


<div class="ats-ticket-replyarea">
<form class="akeeba-form--horizontal" action="index.php" method="post" <?php echo $quickreply ? '' : 'name="adminForm" id="adminForm"' ?> enctype="multipart/form-data">
	<div class="ats-ticket-replyarea-content bbcode">
		<?php
			$contents = '';
			if(Editor::isEditorBBcode())
            {
				$name = 'content';
                $id   = 'bbcode';
			}
            else
            {
				$name = 'content_html';
                $id   = 'ats-content';
			}

			if(isset($this->item) && $this->item instanceof Posts)
            {
                if(Editor::isEditorBBcode())
                {
                    $contents = $this->item->content;
                }
                else
                {
                    $contents = $this->item->content_html;
                }
			}

			$params['cannedreplies'] = true;

			Editor::showEditor($name, $id, $contents, '95%', 400, 80, 20, $params);
		?>
	</div>

    <div class="akeeba-container--50-50">
        <div>
            <div class="ats-ticket-replyarea-timetracking">
            @if(ComponentParams::getParam('showcredits', 0))
                <div class="akeeba-form-group">
                    <label for="ats-credits-charge">@lang('COM_ATS_POSTS_CREDITS_CHARGE')</label>
                    <div class="akeeba-input-group">
                        <input type="text" name="extracredits" id="ats-credits-charge" value="" />
                        <span>@lang('COM_ATS_TICKETS_USERINFO_CREDITS')</span>
                    </div>
                </div>
            @endif
                <div class="akeeba-form-group">
                    <label for="ats-timespent">
                        @lang('COM_ATS_POSTS_LBL_TIMESPENT')
                    </label>
                    <div class="akeeba-input-group">
                        <input type="text" name="timespent" id="ats-timespent" value="{{{ $this->item->timespent }}}" />
                        <span>@lang('COM_ATS_POSTS_LBL_TIMESPENT_MINUTES')</span>
                    </div>
                </div>
            </div>

    @if(!($this->item instanceof Posts))
            <div class="ats-ticket-replyarea-attachment akeeba-form-group">
                <label>@lang('COM_ATS_POSTS_MSG_ADDATTACHMENT')</label>
                <div class="attachmentHolder">
                    <div class="attachmentWrapper">
                        <input type="file" name="attachedfile[]" size="10" />
                        <a class="akeeba-btn--mini-dark" href="javascript:void(0)" style="display: none">@lang('COM_ATS_COMMON_REMOVE')</a>
                    </div>
                </div>

            </div>
            <div class="akeeba-form-group--pull-right">
                <div class="akeeba-form-group--actions">
                    <a href="javascript:void(0);" class="akeeba-btn--grey" id="addAttachment">@lang('COM_ATS_POSTS_ADD_ATTACHMENT')</a>
                </div>
            </div>
        </div>
    </div>

	<div class="ats-ticket-replyarea-postbutton">
		<input class="akeeba-btn--primary" type="submit" value="@lang('COM_ATS_POSTS_MSG_POST')" />
	</div>
	@endif

    <input type="hidden" name="option" value="com_ats" />
    <input type="hidden" name="view" value="Posts" />
    <input type="hidden" name="task" value="save" />
    <input type="hidden" name="ats_ticket_id" value="{{{ $ats_ticket_id }}}" />
    <input type="hidden" name="ats_post_id" value="{{{ $ats_post_id }}}" />
    <input type="hidden" name="@token()" value="1" />
	<?php if(isset($returnURL)): ?>
        <input type="hidden" name="returnurl" value="<?php echo $returnURL ?>" />
	<?php endif; ?>
</form>
</div>
