<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2020 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

/** @var    FOF30\View\DataView\Html $this */
use Akeeba\TicketSystem\Admin\Helper\ComponentParams;use Akeeba\TicketSystem\Admin\Helper\Editor;use Akeeba\TicketSystem\Admin\Helper\Html;use Akeeba\TicketSystem\Admin\Helper\Permissions;

defined('_JEXEC') or die;

/**
 * Renders the Post a Reply section when viewing a ticket. Also used when filing a new ticket.
 *
 * Params passed by the loadAnyTemplate function
 *
 * $category            : Category id
 * $direct              : Controls the field name of the post editor. When false (default) it's something like
 *                        "post[content]", otherwise it's "content".
 * $allow_attachment    : Are attachments allowed?
 * $post_content        : Content of the post stored in the session (previous failed save)
 */

if (!isset($category)) $category = 0;
if (!isset($direct)) $direct = false;
if (!isset($allow_attachment)) $allow_attachment = false;
if (!isset($post_content)) $post_content = '';

$isAdmin = $this->container->platform->getUser()->authorise('core.admin', 'com_ats') || $this->container->platform->getUser()->authorise('core.manage', 'com_ats');
$isManager = Permissions::isManager($category);
$uploadLimit = Html::getUploadLimits();
$allowedExt = Html::allowedExtensions();
$isBBcodeEditor = Editor::isEditorBBcode();
$showCredits = ComponentParams::getParam('showcredits', 0);

$tags = array();

if ($this->item->created_by)
{
	// Get the tags
	/** @var \Akeeba\TicketSystem\Site\Model\Jusers $joomlaModel */
	$joomlaModel = $this->getModel('Jusers');
	$joomlaModel->find($this->item->created_by);

	/** @var \FOF30\Model\DataModel\Collection $collection */
	$collection = $joomlaModel->atstags;
	$tags       = $collection->modelKeys();
	$tags       = array_unique($tags);
}

$timespentMandatory = $this->getContainer()->params->get('timespent_mandatory', 0);
?>
@jhtml('behavior.tooltip')
@jhtml('behavior.modal')
@jhtml('formbehavior.chosen')

{{-- Display a modal message over the ticket post area --}}
@section('post-form-overlay')
    <?php $overlays = Html::loadposition('ats-replyarea-overlay') ?>
    @unless($isManager || empty($overlays))
        @js('media://com_ats/js/modal.js', $this->getContainer()->mediaVersion)
        @inlineJs(<<<JS

;//
var ats_post_overlay_modal;
akeeba.jQuery(document).ready(function($){
    setTimeout(function(){
        var elOverlay = document.getElementById('ats-replyarea-overlay-modal');
        if (!elOverlay) return;

        ats_post_overlay_modal = ats.Modal.open({
            inherit: '#ats-replyarea-overlay-modal',
            width: "80%",
            height: "75%"
        })
    }, 500);
});
JS
    )
        <div id="ats-replyarea-overlay-modal" style="display: none;">
            <div class="akeeba-renderer-fef">
                {{ $overlays }}

                <hr/>
                <a href="javascript:ats_post_overlay_modal.close();" class="akeeba-btn--green">
                    <span class="akion-checkmark-round"></span>
                    @lang('COM_ATS_NEWTICKET_INSTANTREPLY_CLOSEMESSAGE')
                </a>
            </div>
        </div>
    @endunless
@stop

@section('post-form-bbcode-info')
    @if($isBBcodeEditor)
        <div class="ats-ticket-content-info">
            @lang('COM_ATS_NEWTICKET_LBL_YOURREQUEST_INFO')
        </div>
    @endif
@stop

@section('post-form-timespent')
    @if($isManager && ATS_PRO)
        <div class="AKEEBA_MASTER_FORM_STYLING akeeba-form--inline">
            <div class="akeeba-form-group" style="display: inline-flex">
                <label for="ats-timespent">@lang('COM_ATS_POSTS_LBL_TIMESPENT')</label>
                <div class="akeeba-input-group">
                    <input type="text" name="timespent" id="ats-timespent"
                           {{ $timespentMandatory ? 'required="required"' : '' }} value="" />
                    <span>@lang('COM_ATS_POSTS_LBL_TIMESPENT_MINUTES')</span>
                </div>
            </div>

            <div class="akeeba-form-group" style="display: inline-flex">
                <img id="counting" style="display:none"
                     src="@media('media://com_ats/images/throbber.gif')">
            </div>

            <div class="akeeba-form-group--actions" style="margin: 5px 0" style="display: inline-flex">
                <span class="akeeba-btn--small" id="timerBtn">@lang('COM_ATS_TIMER_START')</span>
            </div>
        </div>
    @endif
@stop

@section('post-form-editor')
	<?php
	$editorParams = [
		'buckets'       => $isAdmin && ATS_PRO,
		'ats_ticket_id' => $this->item->ats_ticket_id,
		'cannedreplies' => $isManager,
		'category'      => isset($category) ? $category : null
	];
	?>
    <div class="ats-ticket-replyarea-content bbcode">
        @if($isBBcodeEditor)
            @atsEditor($direct ? 'content' : 'post[content]', 'bbcode', $post_content, '95%', 400, 80, 20, $editorParams)
        @else
            @atsEditor($direct ? 'content_html' : 'post[content_html]', 'ats-content', $post_content, '95%', 400, 80, 20, $editorParams)
        @endif
    </div>
@stop


@section('post-form-credits')
    @if ($isManager && ATS_PRO)
        @if($showCredits)
            <div class="akeeba-form-group">
                <label for="ats-credits-charge">@lang('COM_ATS_POSTS_CREDITS_CHARGE')</label>
                <div>
                    <div class="akeeba-input-group">
                        <input type="text" name="extracredits" id="ats-credits-charge" value="" />
                        <span>@lang('COM_ATS_TICKETS_USERINFO_CREDITS')</span>
                    </div>
                </div>
            </div>
        @endif
    @endif
@stop

@section('post-form-usertags')
    @if ($isManager)
        <div class="akeeba-form-group">
            <label for="usertags">@lang('COM_ATS_COMMON_USER_TAGS')</label>
            {{ \Akeeba\TicketSystem\Admin\Helper\Select::usertags('usertags[]', $tags, array('class' => 'advancedSelect', 'multiple' => 'multiple', 'size' => 5)) }}
        </div>
    @endif
@stop

@section('post-form-attachments')
    @if ($allow_attachment)
        <?php $js = <<<JS
akeeba.jQuery(document).ready(function(jQuery){
    jQuery('#addAttachment').click(function(){
        if(jQuery('input[name="attachedfile[]"]').length >= 10)
        {
            return false;
        }

        var clone = jQuery('.ats-ticket-replyarea-attachment').first().clone();
        clone.children('label').html('').addClass('col-xs-0');
        clone.children('.attFileField').children().first().val('');
        clone.children('div').children('.attButtonField').children().first().css('display', 'inline-block');

        clone.appendTo('.ats-attachments');
    })
});

JS;
?>
        @inlineJs($js)

        <div class="ats-ticket-replyarea-attachment akeeba-form-group">
            <label for="attachedfile">@lang('COM_ATS_NEWTICKET_LBL_ATTACHMENT')</label>
            <div>
                <span class="attFileField">
                    <input type="file" name="attachedfile[]" />
                </span>
                <span class="attButtonField">
                    <a class="akeeba-btn--dark-small" href="javascript:void(0);"
                       onclick="akeeba.jQuery(this).parent().parent().parent().remove();" style="display: none;">
                        @lang('COM_ATS_COMMON_REMOVE')
                    </a>
                </span>
            </div>
        </div>

        <div class="ats-attachments"></div>

        <div class="ats-ticket-replyarea-attachment-help akeeba-form-group--pull-right">
            <div>
                <a href="javascript:void(0);" class="akeeba-btn--primary" id="addAttachment">
                    <span class="akion-plus-round"></span>
                    @lang('COM_ATS_POSTS_ADD_ATTACHMENT')
                </a>

                <p>
                    @sprintf('COM_ATS_NEWTICKET_LBL_ATTACHMENT_MAXSIZE',$uploadLimit)
                    @sprintf('COM_ATS_NEWTICKET_LBL_ATTACHMENT_ALLOWED_EXTENSIONS', implode(', ',$allowedExt))
                </p>
            </div>
        </div>
    @endif
@stop

@yield('post-form-overlay')
@yield('post-form-bbcode-info')
@yield('post-form-timespent')
@yield('post-form-editor')
@yield('post-form-credits')
@yield('post-form-usertags')
@yield('post-form-attachments')