/*
 * @package   ats
 * @copyright Copyright (c)2011-2020 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

if (typeof (akeeba) === "undefined")
{
    var akeeba = {};
}

if (typeof (akeeba.jQuery) === "undefined")
{
    akeeba.jQuery = window.jQuery.noConflict();
}

if (typeof (akeeba.ats) === "undefined")
{
    akeeba.ats = {};
}

if (typeof (akeeba.ats.cpanel) === "undefined")
{
    akeeba.ats.cpanel = {
        ticketPoints: [],
        postPoints:   [],
        ticketsChart: null,
        sparedChart:  null,
    };
}

/**
 * Load and render the graph of tickets and posts the last 10 days
 */
akeeba.ats.cpanel.loadTicketsAndPosts = function () {
    (function ($) {
        $.getJSON("index.php?option=com_ats&view=ControlPanel&task=getTicketStats&format=raw", {
            "limitstart": 0,
            "limit":      0,
            "created_on": {
                "method":   "search",
                "operator": ">=",
                "value":    xday
            }
        }, function (data) {
            $.each(data, function (index, item) {
                akeeba.ats.cpanel.ticketPoints.push({
                    "t": item.date,
                    "y": item.tickets
                });
                akeeba.ats.cpanel.postPoints.push({
                    "t": item.date,
                    "y": item.posts,
                });
            });

            document.getElementById("akthrobber").style.display = "none";

            akeeba.ats.cpanel.renderTicketsAndPostsGraph();
        });
    })(akeeba.jQuery);
};

/**
 * Render the graph of tickets and posts the last 10 days
 */
akeeba.ats.cpanel.renderTicketsAndPostsGraph = function () {
    var chartOptions = {
        type:    "bar",
        data:    {
            datasets: [
                {
                    label:       "Posts",
                    data:        akeeba.ats.cpanel.postPoints,
                    borderColor: "#F0AD4E",
                    fill:        false,
                    yAxisID:     "y-axis-posts",
                    type:        "line"
                },
                {
                    label:           "Tickets",
                    data:            akeeba.ats.cpanel.ticketPoints,
                    backgroundColor: "#40B5B8",
                    fill:            true,
                    yAxisID:         "y-axis-tickets",
                },

            ]
        },
        options: {
            legend: {
                display: false
            },
            scales: {
                xAxes: [
                    {
                        type: "time",
                        time: {
                            round:         "day",
                            tooltipFormat: "ll",
                            unit:          "day",
                            minUnit:       "day"
                        }
                    }
                ],
                yAxes: [
                    {
                        id:       "y-axis-tickets",
                        position: "left",
                        ticks:    {
                            beginAtZero: true
                        }
                    }, {
                        id:        "y-axis-posts",
                        position:  "right",
                        ticks:     {
                            beginAtZero: true
                        },
                        gridLines: {
                            drawOnChartArea: false
                        }
                    }
                ]
            }
        }
    };

    if (akeeba.ats.cpanel.ticketsChart)
    {
        akeeba.ats.cpanel.ticketsChart.destroy();
        akeeba.ats.cpanel.ticketsChart = null;
    }

    akeeba.ats.cpanel.ticketsChart = new Chart(document.getElementById("akticketschartCanvas"), chartOptions);
};

akeeba.ats.cpanel.loadSparedTickets = function () {
    (function ($) {
        $.ajax("index.php?option=com_ats&view=TicketStatistics&task=showspared&layout=spared&format=json", {
            dataType: "json",
            cache:    false,
            data:     {
                "limitstart":  0,
                "limit":       0,
                created_since: $("#sinceSpared").val(),
                created_until: $("#untilSpared").val()
            },
            success:  function (data) {
                document.getElementById("akthrobberspared").style.display = "none";

                akeeba.ats.cpanel.renderSparedTicketsGraph(data);
            }
        });
    })(akeeba.jQuery);
};

akeeba.ats.cpanel.renderSparedTicketsGraph = function (data) {
    var chartOptions = {
        type:    "bar",
        data:    {
            datasets: [
                {
                    label:           "Saved %",
                    data:            data.saved,
                    backgroundColor: "#93C34E",
                    fill:            true,
                    yAxisID:         "y-axis-saved",
                }
            ]
        },
        options: {
            legend: {
                display: false
            },
            scales: {
                xAxes: [
                    {
                        type:   "category",
                        labels: data.categories
                    }
                ],
                yAxes: [
                    {
                        id:       "y-axis-saved",
                        position: "left",
                        ticks:    {
                            beginAtZero: true
                        }
                    }
                ]
            }
        }
    };

    if (akeeba.ats.cpanel.sparedChart)
    {
        akeeba.ats.cpanel.sparedChart.destroy();
        akeeba.ats.cpanel.sparedChart = null;
    }

    akeeba.ats.cpanel.sparedChart = new Chart(document.getElementById("aksparedticketsCanvas"), chartOptions);
};

/**
 * Convert the user feedback recapitulation table into a live, sortable table.
 */
akeeba.ats.cpanel.applyUserFeedbackTable = function () {
    if (typeof show_feedback === "undefined")
    {
        return;
    }

    if (!show_feedback)
    {
        return;
    }

    if (!document.getElementById("userfeedback"))
    {
        return;
    }

    (function ($) {
        $("#userfeedback").dataTable({
            "sDom":            "<<l>r>t<<i><p>>",
            "sPaginationType": "bootstrap"
        });

        $.extend($.fn.dataTableExt.oStdClasses, {
            "sWrapper": "dataTables_wrapper akeeba-form--inline"
        });
    })(akeeba.jQuery);
};

/**
 * Check for ATS updates and show a notification about it
 */
akeeba.ats.cpanel.showUpdateNotification = function () {
    // Make sure we don't need a download ID to be entered first
    if (typeof needsdlid === "undefined")
    {
        return;
    }

    if (needsdlid)
    {
        return;
    }

    // Ask Joomla if it's got any updates for us
    akeeba.jQuery.ajax("index.php?option=com_ats&view=ControlPanels&task=updateinfo&tmpl=component", {
        success: function (msg, textStatus, jqXHR) {
            // Get rid of junk before and after data
            var match = msg.match(/###([\s\S]*?)###/);
            data      = match[1];

            if (data.length)
            {
                document.getElementById("updateNotice").innerHTML = data;
            }
        }
    });
};

(function ($) {
    $(document).ready(function () {
        akeeba.ats.cpanel.applyUserFeedbackTable();

        // Load the graphs
        akeeba.ats.cpanel.loadTicketsAndPosts();
        akeeba.ats.cpanel.loadSparedTickets();

        // Attach a handler to the spared tickets graph's reload button
        akeeba.jQuery("#reloadSpared").click(akeeba.ats.cpanel.loadSparedTickets);

        // Check for ATS updates and show a notification about it
        akeeba.ats.cpanel.showUpdateNotification();
    });
})(akeeba.jQuery);
